package com.ynet.life.sujrb.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.StringTokenizer;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.Region;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/ReportDownloadGuaBalanceAction.class */
public class ReportDownloadGuaBalanceAction extends LifeAction {
    private static final String FIELD_SEPERATOR = "||";
    protected String fileTypeField;
    protected String fileNameField;
    protected String titleField;
    protected String encoding;
    private List outputFields;
    private List outputFormats;
    private List titles;
    private String iCollName;

    public String execute(Context ctx) throws GENEException {
        try {
            ctx.terminate();
            List recordList = initFromContext(ctx, this.iCollName);
            String fileType = (String) ctx.get(this.fileTypeField);
            String filePathName = getFileName(fileType, this.fileNameField);
            writeToFile(recordList, filePathName, this.encoding);
            ctx.put("downloadFile", filePathName);
            return "0";
        } catch (Exception ex) {
            Trace.logError("LifeAction", "RZPT90001:报表下载处理出错", ex);
            throw new TranFailException("RZPT90001", "报表下载处理出错", false);
        }
    }

    private void writeToFile(List recordList, String filePathName, String encoding) throws TranFailException {
        HSSFWorkbook workBook = new HSSFWorkbook();
        HSSFSheet sheet = workBook.createSheet();
        HSSFRow row = sheet.createRow(0);
        row.setHeightInPoints(20.0f);
        HSSFFont font = workBook.createFont();
        font.setFontName("黑体");
        font.setColor((short) 8);
        font.setFontHeight((short) 300);
        row.createCell(0);
        sheet.addMergedRegion(new Region(0, (short) 0, 0, (short) 2));
        HSSFCellStyle cellStyle = workBook.createCellStyle();
        cellStyle.setAlignment((short) 2);
        cellStyle.setFont(font);
        row.getCell(0).setCellStyle(cellStyle);
        row.getCell(0).setCellValue(new HSSFRichTextString("在保余额变动表"));
        HSSFFont titleFont = workBook.createFont();
        titleFont.setFontName("黑体");
        titleFont.setColor((short) 8);
        titleFont.setFontHeight((short) 250);
        HSSFCellStyle titleCellStyle = workBook.createCellStyle();
        titleCellStyle.setAlignment((short) 2);
        titleCellStyle.setVerticalAlignment((short) 1);
        titleCellStyle.setFont(titleFont);
        Map record = (Map) recordList.iterator().next();
        HSSFRow createRow = sheet.createRow(1);
        createRow.setHeightInPoints(20.0f);
        sheet.setColumnWidth(0, Short.parseShort("6000"));
        HSSFCell cell = createRow.createCell(0);
        cell.setCellStyle(titleCellStyle);
        cell.setCellValue(new HSSFRichTextString(""));
        HSSFCell RowOnecell1 = createRow.createCell(1);
        RowOnecell1.setCellStyle(titleCellStyle);
        RowOnecell1.setCellValue(new HSSFRichTextString("担保金额（万元）"));
        HSSFCell RowOnecell2 = createRow.createCell(2);
        RowOnecell2.setCellStyle(titleCellStyle);
        RowOnecell2.setCellValue(new HSSFRichTextString("客户数量（个）"));
        HSSFRow createRow2 = sheet.createRow(2);
        createRow2.setHeightInPoints(20.0f);
        sheet.setColumnWidth(1, Short.parseShort("6000"));
        HSSFCell RowTowcellone = createRow2.createCell(0);
        RowTowcellone.setCellStyle(titleCellStyle);
        RowTowcellone.setCellValue(new HSSFRichTextString("期初在保"));
        createRow2.createCell(1).setCellValue(new HSSFRichTextString(record.get("startAmt").toString()));
        createRow2.createCell(2).setCellValue(new HSSFRichTextString(record.get("startCorNum").toString()));
        HSSFRow createRow3 = sheet.createRow(3);
        createRow3.setHeightInPoints(20.0f);
        sheet.setColumnWidth(2, Short.parseShort("6000"));
        HSSFCell RowThreecellone = createRow3.createCell(0);
        RowThreecellone.setCellStyle(titleCellStyle);
        RowThreecellone.setCellValue(new HSSFRichTextString("本期增加担保"));
        createRow3.createCell(1).setCellValue(new HSSFRichTextString(record.get("addAmt").toString()));
        createRow3.createCell(2).setCellValue(new HSSFRichTextString(record.get("addCorNum").toString()));
        HSSFRow createRow4 = sheet.createRow(4);
        createRow4.setHeightInPoints(20.0f);
        HSSFCell RowFourcellone = createRow4.createCell(0);
        RowFourcellone.setCellStyle(titleCellStyle);
        RowFourcellone.setCellValue(new HSSFRichTextString("本期解除担保"));
        createRow4.createCell(1).setCellValue(new HSSFRichTextString(record.get("releaseAmt").toString()));
        createRow4.createCell(2).setCellValue(new HSSFRichTextString(record.get("releaseCorNum").toString()));
        HSSFRow createRow5 = sheet.createRow(5);
        createRow5.setHeightInPoints(20.0f);
        HSSFCell RowFivecellone = createRow5.createCell(0);
        RowFivecellone.setCellStyle(titleCellStyle);
        RowFivecellone.setCellValue(new HSSFRichTextString("期末在保"));
        createRow5.createCell(1).setCellValue(new HSSFRichTextString(record.get("endAmt").toString()));
        createRow5.createCell(2).setCellValue(new HSSFRichTextString(record.get("endCorNum").toString()));
        FileOutputStream fileOut = null;
        try {
            try {
                fileOut = new FileOutputStream(filePathName);
                workBook.write(fileOut);
                try {
                    fileOut.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (Throwable th) {
                if (fileOut != null) {
                    try {
                        fileOut.close();
                    } catch (IOException ex2) {
                        Trace.logError("LifeFile", "I/O异常", ex2);
                        throw new TranFailException("EBLN0000", "I/O异常", ex2);
                    }
                }
                throw th;
            }
        } catch (IOException ex3) {
            Trace.logError("LifeFile", "文件写入失败", ex3);
            throw new TranFailException("EBLN0000", "文件写入失败", ex3);
        }
    }

    private String getLanguage(Context context) {
        if (context == null) {
            return null;
        }
        String language = null;
        try {
            language = (String) context.getDataValue("session_language");
        } catch (GENEException unused) {
        }
        return language;
    }

    protected String getFileName(String fileType, String fileName) throws TranFailException {
        String rootPath = LifeStandard.getSelfDefineSettingsValue("tempDownloadDir");
        String folder = String.valueOf(LifeStandard.getServerTime("yyyyMMdd")) + LifeFile.DIR_SEPARATOR;
        LifeFile.makeMultiDirectory(rootPath, folder);
        String filePathName = String.valueOf(LifeStandard.getServerTime("HHmmssSSS")) + new Random().nextInt(1000) + fileName + '.' + fileType;
        return String.valueOf(rootPath) + folder + filePathName;
    }

    public List initFromContext(Map context, String iCollName) throws TranFailException {
        List recordList = new ArrayList();
        for (Map kcoll : (List) context.get(iCollName)) {
            recordList.add(kcoll);
        }
        return recordList;
    }

    public void setOutputFields(String outputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFields = result;
    }

    public void setOutputFormats(String outputFormats) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFormats, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFormats = result;
    }

    public void setTitles(String titles) {
        List title = new ArrayList();
        StringTokenizer toke = new StringTokenizer(titles, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            title.add(input);
        }
        this.titles = title;
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setFileTypeField(String fileTypeField) {
        this.fileTypeField = fileTypeField;
    }

    public void setTitleField(String titleField) {
        this.titleField = titleField;
    }

    public void setFileNameField(String fileNameField) {
        this.fileNameField = fileNameField;
    }

    public void setEncoding(String encoding) {
        this.encoding = encoding;
    }
}
